@@ -46,7 +46,7 @@ sub _monikerize {
 sub run_tests {
     my $self = shift;
 
-    plan tests => 136 + ($self->{extra}->{count} || 0);
+    plan tests => 134 + ($self->{extra}->{count} || 0);
 
     $self->create();
 
@@ -89,16 +89,17 @@ sub run_tests {
         };
         ok(!$@, "Loader initialization") or diag $@;
         if($self->{skip_rels}) {
-            is(scalar(@loader_warnings), 0)
-              or diag "Did not get the expected 0 warnings.  Warnings are: "
-                . join('',@loader_warnings);
-            ok(1);
+            SKIP: {
+                is(scalar(@loader_warnings), 0, "No loader warnings")
+                    or diag @loader_warnings;
+                skip "No missing PK warnings without rels", 1;
+            }
         }
         else {
-            is(scalar(@loader_warnings), 1)
-              or diag "Did not get the expected 1 warning.  Warnings are: "
-                . join('',@loader_warnings);
-            like($loader_warnings[0], qr/loader_test9 has no primary key/i);
+            is(scalar(@loader_warnings), 1, "Expected loader warning")
+                or diag @loader_warnings;
+            like($loader_warnings[0], qr/loader_test9 has no primary key/i,
+                 "Missing PK warning");
         }
     }
 
@@ -133,9 +134,7 @@ sub run_tests {
     isa_ok( $rsobj24, "DBIx::Class::ResultSet" );
 
     my @columns_lt2 = $class2->columns;
-    is($columns_lt2[0], 'id', "Column Ordering 0");
-    is($columns_lt2[1], 'dat', "Column Ordering 1");
-    is($columns_lt2[2], 'dat2', "Column Ordering 2");
+    is_deeply( \@columns_lt2, [ qw/id dat dat2/ ], "Column Ordering" );
 
     my %uniq1 = $class1->unique_constraints;
     my $uniq1_test = 0;
@@ -146,7 +145,7 @@ sub run_tests {
            last;
         }
     }
-    ok($uniq1_test) or diag "Unique constraints not working";
+    ok($uniq1_test, "Unique constraint");
 
     my %uniq2 = $class2->unique_constraints;
     my $uniq2_test = 0;
@@ -159,7 +158,7 @@ sub run_tests {
             last;
         }
     }
-    ok($uniq2_test) or diag "Multi-col unique constraints not working";
+    ok($uniq2_test, "Multi-col unique constraint");
 
     is($moniker2, 'LoaderTest2X', "moniker_map testing");
 
@@ -200,7 +199,8 @@ sub run_tests {
         SKIP: {
             skip "Pre-requisite test failed", 1 if $skip_tcomp;
             is( $class1->dbix_class_testcomponent,
-                'dbix_class_testcomponent works' );
+                'dbix_class_testcomponent works',
+                'Additional Component' );
         }
 
         SKIP: {
@@ -210,52 +210,50 @@ sub run_tests {
             SKIP: {
                 skip "Pre-requisite test failed", 1 if $skip_trscomp;
                 is( $rsobj1->dbix_class_testrscomponent,
-                    'dbix_class_testrscomponent works' );
+                    'dbix_class_testrscomponent works',
+                    'ResultSet component' );
             }
         }
 
         SKIP: {
             skip "Pre-requisite test failed", 1 if $skip_cmeth;
-            is( $class1->loader_test1_classmeth, 'all is well' );
+            is( $class1->loader_test1_classmeth, 'all is well', 'Class method' );
         }
 
-        # XXX put this back in when the TODO above works...
-        #SKIP: {
-        #    skip "Pre-requisite test failed", 1 if $skip_rsmeth;
-        #    is( $rsobj1->loader_test1_rsmeth, 'all is still well' );
-        #}
+        SKIP: {
+            skip "Pre-requisite test failed", 1 if $skip_rsmeth;
+            is( $rsobj1->loader_test1_rsmeth, 'all is still well', 'Result set method' );
+        }
     }
 
     SKIP: {
         skip "This vendor doesn't detect auto-increment columns", 1
             if $self->{no_auto_increment};
 
-        is( $class1->column_info('id')->{is_auto_increment}, 1,
-            'Setting is_auto_incrment works'
-        );
+        ok( $class1->column_info('id')->{is_auto_increment}, 'is_auto_incrment detection' );
     }
 
     my $obj    = $rsobj1->find(1);
-    is( $obj->id,  1 );
-    is( $obj->dat, "foo" );
-    is( $rsobj2->count, 4 );
+    is( $obj->id,  1, "Find got the right row" );
+    is( $obj->dat, "foo", "Column value" );
+    is( $rsobj2->count, 4, "Count" );
     my $saved_id;
     eval {
         my $new_obj1 = $rsobj1->create({ dat => 'newthing' });
         $saved_id = $new_obj1->id;
     };
-    ok(!$@) or diag "Died during create new record using a PK::Auto key: $@";
-    ok($saved_id) or diag "Failed to get PK::Auto-generated id";
+    ok(!$@, "Inserting new record using a PK::Auto key didn't die") or diag $@;
+    ok($saved_id, "Got PK::Auto-generated id");
 
     my $new_obj1 = $rsobj1->search({ dat => 'newthing' })->first;
-    ok($new_obj1) or diag "Cannot find newly inserted PK::Auto record";
-    is($new_obj1->id, $saved_id);
+    ok($new_obj1, "Found newly inserted PK::Auto record");
+    is($new_obj1->id, $saved_id, "Correct PK::Auto-generated id");
 
     my ($obj2) = $rsobj2->search({ dat => 'bbb' })->first;
     is( $obj2->id, 2 );
 
     SKIP: {
-        skip $self->{skip_rels}, 69 if $self->{skip_rels};
+        skip $self->{skip_rels}, 96 if $self->{skip_rels};
 
         my $moniker3 = $monikers->{loader_test3};
         my $class3   = $classes->{loader_test3};
@@ -377,7 +375,7 @@ sub run_tests {
         my $obj4 = $rsobj4->find(123);
         isa_ok( $obj4->fkid_singular, $class3);
 
-        ok($class4->column_info('fkid')->{is_foreign_key});
+        ok($class4->column_info('fkid')->{is_foreign_key}, 'Foreign key detected');
 
         my $obj3 = $rsobj3->find(1);
         my $rs_rel4 = $obj3->search_related('loader_test4zes');
@@ -385,96 +383,96 @@ sub run_tests {
 
         # find on multi-col pk
         my $obj5 = $rsobj5->find({id1 => 1, id2 => 1});
-        is( $obj5->id2, 1 );
+        is( $obj5->id2, 1, "Find on multi-col PK" );
 
         # mulit-col fk def
         my $obj6 = $rsobj6->find(1);
         isa_ok( $obj6->loader_test2, $class2);
         isa_ok( $obj6->loader_test5, $class5);
 
-        ok($class6->column_info('loader_test2')->{is_foreign_key});
-        ok($class6->column_info('id')->{is_foreign_key});
-        ok($class6->column_info('id2')->{is_foreign_key});
+        ok($class6->column_info('loader_test2')->{is_foreign_key}, 'Foreign key detected');
+        ok($class6->column_info('id')->{is_foreign_key}, 'Foreign key detected');
+        ok($class6->column_info('id2')->{is_foreign_key}, 'Foreign key detected');
 
         # fk that references a non-pk key (UNIQUE)
         my $obj8 = $rsobj8->find(1);
         isa_ok( $obj8->loader_test7, $class7);
 
-        ok($class8->column_info('loader_test7')->{is_foreign_key});
+        ok($class8->column_info('loader_test7')->{is_foreign_key}, 'Foreign key detected');
 
         # test double-fk 17 ->-> 16
         my $obj17 = $rsobj17->find(33);
 
         my $rs_rel16_one = $obj17->loader16_one;
         isa_ok($rs_rel16_one, $class16);
-        is($rs_rel16_one->dat, 'y16');
+        is($rs_rel16_one->dat, 'y16', "Multiple FKs to same table");
 
-        ok($class17->column_info('loader16_one')->{is_foreign_key});
+        ok($class17->column_info('loader16_one')->{is_foreign_key}, 'Foreign key detected');
 
         my $rs_rel16_two = $obj17->loader16_two;
         isa_ok($rs_rel16_two, $class16);
-        is($rs_rel16_two->dat, 'z16');
+        is($rs_rel16_two->dat, 'z16', "Multiple FKs to same table");
 
-        ok($class17->column_info('loader16_two')->{is_foreign_key});
+        ok($class17->column_info('loader16_two')->{is_foreign_key}, 'Foreign key detected');
 
         my $obj16 = $rsobj16->find(2);
         my $rs_rel17 = $obj16->search_related('loader_test17_loader16_ones');
         isa_ok($rs_rel17->first, $class17);
-        is($rs_rel17->first->id, 3);
+        is($rs_rel17->first->id, 3, "search_related with multiple FKs from same table");
         
         # XXX test m:m 18 <- 20 -> 19
-        ok($class20->column_info('parent')->{is_foreign_key});
-        ok($class20->column_info('child')->{is_foreign_key});
+        ok($class20->column_info('parent')->{is_foreign_key}, 'Foreign key detected');
+        ok($class20->column_info('child')->{is_foreign_key}, 'Foreign key detected');
         
         # XXX test double-fk m:m 21 <- 22 -> 21
-        ok($class22->column_info('parent')->{is_foreign_key});
-        ok($class22->column_info('child')->{is_foreign_key});
+        ok($class22->column_info('parent')->{is_foreign_key}, 'Foreign key detected');
+        ok($class22->column_info('child')->{is_foreign_key}, 'Foreign key detected');
 
         # test double multi-col fk 26 -> 25
         my $obj26 = $rsobj26->find(33);
 
         my $rs_rel25_one = $obj26->loader_test25_id_rel1;
         isa_ok($rs_rel25_one, $class25);
-        is($rs_rel25_one->dat, 'x25');
+        is($rs_rel25_one->dat, 'x25', "Multiple multi-col FKs to same table");
 
-        ok($class26->column_info('id')->{is_foreign_key});
-        ok($class26->column_info('rel1')->{is_foreign_key});
-        ok($class26->column_info('rel2')->{is_foreign_key});
+        ok($class26->column_info('id')->{is_foreign_key}, 'Foreign key detected');
+        ok($class26->column_info('rel1')->{is_foreign_key}, 'Foreign key detected');
+        ok($class26->column_info('rel2')->{is_foreign_key}, 'Foreign key detected');
 
         my $rs_rel25_two = $obj26->loader_test25_id_rel2;
         isa_ok($rs_rel25_two, $class25);
-        is($rs_rel25_two->dat, 'y25');
+        is($rs_rel25_two->dat, 'y25', "Multiple multi-col FKs to same table");
 
         my $obj25 = $rsobj25->find(3,42);
         my $rs_rel26 = $obj25->search_related('loader_test26_id_rel1s');
         isa_ok($rs_rel26->first, $class26);
-        is($rs_rel26->first->id, 3);
+        is($rs_rel26->first->id, 3, "search_related with multiple multi-col FKs from same table");
 
         # test one-to-one rels
         my $obj27 = $rsobj27->find(1);
         my $obj28 = $obj27->loader_test28;
         isa_ok($obj28, $class28);
-        is($obj28->get_column('id'), 1);
+        is($obj28->get_column('id'), 1, "One-to-one relationship with PRIMARY FK");
 
-        ok($class28->column_info('id')->{is_foreign_key});
+        ok($class28->column_info('id')->{is_foreign_key}, 'Foreign key detected');
 
         my $obj29 = $obj27->loader_test29;
         isa_ok($obj29, $class29);
-        is($obj29->id, 1);
+        is($obj29->id, 1, "One-to-one relationship with UNIQUE FK");
 
-        ok($class29->column_info('fk')->{is_foreign_key});
+        ok($class29->column_info('fk')->{is_foreign_key}, 'Foreign key detected');
 
         $obj27 = $rsobj27->find(2);
-        is($obj27->loader_test28, undef);
-        is($obj27->loader_test29, undef);
+        is($obj27->loader_test28, undef, "Undef for missing one-to-one row");
+        is($obj27->loader_test29, undef, "Undef for missing one-to-one row");
 
         # test outer join for nullable referring columns:
         SKIP: {
           skip "unreliable column info from db driver",11 unless 
             ($class32->column_info('rel2')->{is_nullable});
 
-          ok($class32->column_info('rel1')->{is_foreign_key});
-          ok($class32->column_info('rel2')->{is_foreign_key});
+          ok($class32->column_info('rel1')->{is_foreign_key}, 'Foreign key detected');
+          ok($class32->column_info('rel2')->{is_foreign_key}, 'Foreign key detected');
           
           my $obj32 = $rsobj32->find(1,{prefetch=>[qw/rel1 rel2/]});
           my $obj34 = $rsobj34->find(
@@ -484,22 +482,22 @@ sub run_tests {
           isa_ok($obj32,$class32) or $skip_outerjoin = 1;
           isa_ok($obj34,$class34) or $skip_outerjoin = 1;
 
-          ok($class34->column_info('id')->{is_foreign_key});
-          ok($class34->column_info('rel1')->{is_foreign_key});
-          ok($class34->column_info('rel2')->{is_foreign_key});
+          ok($class34->column_info('id')->{is_foreign_key}, 'Foreign key detected');
+          ok($class34->column_info('rel1')->{is_foreign_key}, 'Foreign key detected');
+          ok($class34->column_info('rel2')->{is_foreign_key}, 'Foreign key detected');
 
           SKIP: {
             skip "Pre-requisite test failed", 4 if $skip_outerjoin;
             my $rs_rel31_one = $obj32->rel1;
             my $rs_rel31_two = $obj32->rel2;
-            isa_ok($rs_rel31_one,$class31);
-            is($rs_rel31_two,undef);
+            isa_ok($rs_rel31_one, $class31);
+            is($rs_rel31_two, undef);
 
             my $rs_rel33_one = $obj34->loader_test33_id_rel1;
             my $rs_rel33_two = $obj34->loader_test33_id_rel2;
 
             isa_ok($rs_rel33_one,$class33);
-            is($rs_rel33_two,undef);
+            is($rs_rel33_two, undef);
 
           }
         }
@@ -521,37 +519,35 @@ sub run_tests {
             isa_ok( $rsobj10, "DBIx::Class::ResultSet" ); 
             isa_ok( $rsobj11, "DBIx::Class::ResultSet" );
 
-            ok($class10->column_info('loader_test11')->{is_foreign_key});
-            ok($class11->column_info('loader_test10')->{is_foreign_key});
+            ok($class10->column_info('loader_test11')->{is_foreign_key}, 'Foreign key detected');
+            ok($class11->column_info('loader_test10')->{is_foreign_key}, 'Foreign key detected');
 
             my $obj10 = $rsobj10->create({ subject => 'xyzzy' });
 
             $obj10->update();
-            ok( defined $obj10, '$obj10 is defined' );
+            ok( defined $obj10, 'Create row' );
 
             my $obj11 = $rsobj11->create({ loader_test10 => $obj10->id() });
             $obj11->update();
-            ok( defined $obj11, '$obj11 is defined' );
+            ok( defined $obj11, 'Create related row' );
 
             eval {
                 my $obj10_2 = $obj11->loader_test10;
                 $obj10_2->loader_test11( $obj11->id11() );
                 $obj10_2->update();
             };
-            is($@, '', 'No errors after eval{}');
+            ok(!$@, "Setting up circular relationship");
 
             SKIP: {
-                skip 'Previous eval block failed', 3
-                    unless ($@ eq '');
+                skip 'Previous eval block failed', 3 if $@;
         
                 my $results = $rsobj10->search({ subject => 'xyzzy' });
-                is( $results->count(), 1,
-                    'One $rsobj10 returned from search' );
+                is( $results->count(), 1, 'No duplicate row created' );
 
                 my $obj10_3 = $results->first();
                 isa_ok( $obj10_3, $class10 );
                 is( $obj10_3->loader_test11()->id(), $obj11->id(),
-                    'found same $rsobj11 object we expected' );
+                    'Circular rel leads back to same row' );
             }
         }
 
@@ -570,9 +566,9 @@ sub run_tests {
             isa_ok( $rsobj12, "DBIx::Class::ResultSet" ); 
             isa_ok( $rsobj13, "DBIx::Class::ResultSet" );
 
-            ok($class13->column_info('id')->{is_foreign_key});
-            ok($class13->column_info('loader_test12')->{is_foreign_key});
-            ok($class13->column_info('dat')->{is_foreign_key});
+            ok($class13->column_info('id')->{is_foreign_key}, 'Foreign key detected');
+            ok($class13->column_info('loader_test12')->{is_foreign_key}, 'Foreign key detected');
+            ok($class13->column_info('dat')->{is_foreign_key}, 'Foreign key detected');
 
             my $obj13 = $rsobj13->find(1);
             isa_ok( $obj13->id, $class12 );
@@ -594,7 +590,7 @@ sub run_tests {
             isa_ok( $rsobj14, "DBIx::Class::ResultSet" ); 
             isa_ok( $rsobj15, "DBIx::Class::ResultSet" );
 
-            ok($class15->column_info('loader_test14')->{is_foreign_key});
+            ok($class15->column_info('loader_test14')->{is_foreign_key}, 'Foreign key detected');
 
             my $obj15 = $rsobj15->find(1);
             isa_ok( $obj15->loader_test14, $class14 );
@@ -622,15 +618,15 @@ sub run_tests {
         $dbh->disconnect;
 
         my @new = $conn->rescan;
-        is(scalar(@new), 1);
-        is($new[0], 'LoaderTest30');
+        is_deeply(\@new, [ qw/LoaderTest30/ ], "Rescan");
 
         my $rsobj30   = $conn->resultset('LoaderTest30');
         isa_ok($rsobj30, 'DBIx::Class::ResultSet');
         my $obj30 = $rsobj30->find(123);
         isa_ok( $obj30->loader_test2, $class2);
 
-        ok($rsobj30->result_source->column_info('loader_test2')->{is_foreign_key});
+        ok($rsobj30->result_source->column_info('loader_test2')->{is_foreign_key},
+           'Foreign key detected');
     }
 
     $self->{extra}->{run}->($conn, $monikers, $classes) if $self->{extra}->{run};
